@@ -19,16 +19,23 @@
  */
 #include "kwaylandintegration.h"
 
-#include <QCoreApplication>
+#include <QGuiApplication>
 #include <QPlatformSurfaceEvent>
+#include <qpa/qplatformnativeinterface.h>
+
+#include <qpa/qplatformnativeinterface.h>
 
 #include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/surface.h>
 #include <KWayland/Client/server_decoration.h>
+#include <KWindowEffects>
 
 using namespace KWayland::Client;
 
+static const QByteArray s_schemePropertyName = QByteArrayLiteral("KDE_COLOR_SCHEME_PATH");
+static const QByteArray s_blurBehindPropertyName = QByteArrayLiteral("ENABLE_BLUR_BEHIND_HINT");
+
 KWaylandIntegration::KWaylandIntegration()
     : QObject()
     , m_decoration(Q_NULLPTR)
@@ -67,12 +74,21 @@ bool KWaylandIntegration::eventFilter(QObject *watched, QEvent *event)
     }
     if (event->type() == QEvent::PlatformSurface) {
         QWindow *w = qobject_cast<QWindow*>(watched);
-        if (!w) {
+        if (!w || w->parent()) {
             return false;
         }
         if (auto e = dynamic_cast<QPlatformSurfaceEvent*>(event)) {
             switch (e->surfaceEventType()) {
             case QPlatformSurfaceEvent::SurfaceCreated: {
+                // set colorscheme hint
+                if (qApp->property(s_schemePropertyName.constData()).isValid()) {
+                    installColorScheme(w);
+                }
+                const auto blurBehindProperty = w->property(s_blurBehindPropertyName.constData());
+                if (blurBehindProperty.isValid()) {
+                    KWindowEffects::enableBlurBehind(w->winId(), blurBehindProperty.toBool());
+                }
+                // create deco
                 Surface *s = Surface::fromWindow(w);
                 if (!s) {
                     return false;
@@ -105,5 +121,29 @@ bool KWaylandIntegration::eventFilter(QObject *watched, QEvent *event)
             }
         }
     }
+    if (event->type() == QEvent::ApplicationPaletteChange) {
+        const auto topLevelWindows = QGuiApplication::topLevelWindows();
+        for (QWindow *w : topLevelWindows) {
+            installColorScheme(w);
+        }
+    }
     return false;
 }
+
+void KWaylandIntegration::installColorScheme(QWindow *w)
+{
+    if (QPlatformNativeInterface *native = qApp->platformNativeInterface()) {
+        if (QPlatformWindow *pw = w->handle()) {
+            native->setWindowProperty(pw, QString::fromUtf8(s_schemePropertyName), qApp->property(s_schemePropertyName.constData()));
+        }
+    }
+}
+
+void KWaylandIntegration::setWindowProperty(QWindow *window, const QByteArray &name, const QByteArray &value)
+{
+    if (QPlatformNativeInterface *nativeInterface = qApp->platformNativeInterface()) {
+        if (QPlatformWindow *platformWindow = window->handle()) {
+            nativeInterface->setWindowProperty(platformWindow, QString::fromUtf8(name), QString::fromUtf8(value));
+        }
+    }
+}
