@@ -22,6 +22,8 @@
 
 #include <QObject>
 
+class QWindow;
+
 namespace KWayland
 {
 namespace Client
@@ -38,9 +40,12 @@ public:
     virtual ~KWaylandIntegration();
     void init();
 
+    void setWindowProperty(QWindow *window, const QByteArray &name, const QByteArray &value);
+
     bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
 private:
+    void installColorScheme(QWindow *w);
     KWayland::Client::ServerSideDecorationManager *m_decoration;
 };
 
